/**
 * @file
 * JavaScript integration between Highcharts and Drupal.
 */
(function ($, Drupal, once) {
  "use strict";

  Drupal.behaviors.chartsHighcharts = {
    attach: function (context, settings) {
      once("chartsHighchartsInit", ".charts-highchart", context).forEach(
        function (element) {
          var $chart = $(element);
          if ($chart.attr("data-chart")) {
            var highchartsConfig = JSON.parse($chart.attr("data-chart"));

            // Specific configurations for 'pie' chart type
            if (highchartsConfig.chart.type === "pie") {
              delete highchartsConfig.plotOptions.bar;
              highchartsConfig.plotOptions.pie = {
                allowPointSelect: true,
                cursor: "pointer",
                showInLegend: true,
                dataLabels: {
                  enabled: highchartsConfig.plotOptions.pie.dataLabels.enabled,
                  format: "{point.y:,.0f}",
                },
                depth: highchartsConfig.plotOptions.pie.depth,
              };
              highchartsConfig.legend.enabled = true;
              highchartsConfig.legend.labelFormatter = function () {
                return this.series.chart.axes[0].categories[this.index];
              };
              highchartsConfig.tooltip.formatter = function () {
                var sliceName =
                  this.series.chart.axes[0].categories[this.point.index];
                return (
                  sliceName +
                  ": " +
                  this.y +
                  this.series.tooltipOptions.valueSuffix
                );
              };
            }

            // General yAxis label formatter
            $.each(highchartsConfig.yAxis, function (index, axis) {
              var suffix = axis.labels.suffix;
              var prefix = axis.labels.prefix;
              axis.labels.formatter = function () {
                return (
                  prefix + this.axis.defaultLabelFormatter.call(this) + suffix
                );
              };

              // Apply yAxis index to the corresponding series
              if (highchartsConfig.series[index]) {
                highchartsConfig.series[index].yAxis = index;
              }
            });

            // Initialize Highcharts
            $chart.highcharts(highchartsConfig);
          }
        }
      );
    },
  };
})(jQuery, Drupal, once);
