<?php

namespace Drupal\charts_highcharts\Settings\Highcharts;

/**
 * Y Axis.
 */
class Yaxis implements \JsonSerializable {

  /**
   * Title.
   *
   * @var mixed
   */
  private $title;

  /**
   * Labels.
   *
   * @var string
   */
  private $labels = '';

  /**
   * Plot Bands.
   *
   * @var array
   */
  private $plotBands = NULL;

  /**
   * Min.
   *
   * @var float
   */
  private $min;

  /**
   * Max.
   *
   * @var float
   */
  private $max;

  /**
   * Categories.
   *
   * @var array
   */
  private $categories = NULL;

  /**
   * Tick Interval.
   *
   * @var mixed
   */
  private $tickInterval;

  /**
   * Tickmark Placement.
   *
   * @var mixed
   */
  private $tickmarkPlacement;

  /**
   * Show First Label.
   *
   * @var mixed
   */
  private $showFirstLabel;

  /**
   * Start On Tick.
   *
   * @var mixed
   */
  private $startOnTick;

  /**
   * Show Last Label.
   *
   * @var mixed
   */
  private $showLastLabel;

  /**
   * End On Tick.
   *
   * @var mixed
   */
  private $endOnTick;

  /**
   * Grid Line Interpolation.
   *
   * @var mixed
   */
  private $gridLineInterpolation = 'circle';

  /**
   * Default is 0 per https://api.highcharts.com/highcharts/yAxis.lineWidth .
   *
   * @var int
   */
  private $lineWidth = 0;

  /**
   * Get Title.
   *
   * @return mixed
   *   Title.
   */
  public function getTitle() {
    return $this->title;
  }

  /**
   * Set Title.
   *
   * @param mixed $title
   *   Title.
   */
  public function setTitle($title) {
    $this->title = $title;
  }

  /**
   * Get Labels.
   *
   * @return string
   *   Labels.
   */
  public function getLabels() {
    return $this->labels;
  }

  /**
   * Set Labels.
   *
   * @param string $labels
   *   Labels.
   */
  public function setLabels($labels) {
    $this->labels = $labels;
  }

  /**
   * Get Plot Bands.
   *
   * @return array
   *   Plot Bands.
   */
  public function getPlotBands() {
    return $this->plotBands;
  }

  /**
   * Set Plot Bands.
   *
   * @param array $plotBands
   *   Plot Bands.
   */
  public function setPlotBands($plotBands) {
    $this->plotBands = $plotBands;
  }

  /**
   * Get Min.
   *
   * @return float
   *   Min.
   */
  public function getMin() {
    return $this->min;
  }

  /**
   * Set Min.
   *
   * @param float $min
   *   Min.
   */
  public function setMin(float $min) {
    $this->min = $min;
  }

  /**
   * Get Max.
   *
   * @return float
   *   Max.
   */
  public function getMax() {
    return $this->max;
  }

  /**
   * Set Max.
   *
   * @param float $max
   *   Max.
   */
  public function setMax(float $max) {
    $this->max = $max;
  }

  /**
   * Get Categories.
   *
   * @return array
   *   Categories.
   */
  public function getCategories() {
    return $this->categories;
  }

  /**
   * Set Categories.
   *
   * @param mixed $categories
   *   Categories.
   */
  public function setCategories($categories) {
    $this->categories = $categories;
  }

  /**
   * Get Tick Interval.
   *
   * @return mixed
   *   Tick Interval.
   */
  public function getTickInterval() {
    return $this->tickInterval;
  }

  /**
   * Set Tick Interval.
   *
   * @param mixed $tickInterval
   *   Tick Interval.
   */
  public function setTickInterval($tickInterval) {
    $this->tickInterval = $tickInterval;
  }

  /**
   * Get Show First Label.
   *
   * @return mixed
   *   Show First Label.
   */
  public function getShowFirstLabel() {
    return $this->showFirstLabel;
  }

  /**
   * Set Show First Label.
   *
   * @param mixed $showFirstLabel
   *   Show First Label.
   */
  public function setShowFirstLabel($showFirstLabel) {
    $this->showFirstLabel = $showFirstLabel;
  }

  /**
   * Get Start On Tick.
   *
   * @return mixed
   *   Start On Tick.
   */
  public function getStartOnTick() {
    return $this->startOnTick;
  }

  /**
   * Set Start On Tick.
   *
   * @param mixed $startOnTick
   *   Start On Tick.
   */
  public function setStartOnTick($startOnTick) {
    $this->startOnTick = $startOnTick;
  }

  /**
   * Get Tickmark Placement.
   *
   * @return mixed
   *   Tickmark Placement.
   */
  public function getTickmarkPlacement() {
    return $this->tickmarkPlacement;
  }

  /**
   * Set Tickmark Placement.
   *
   * @param mixed $tickmarkPlacement
   *   Tickmark Placement.
   */
  public function setTickmarkPlacement($tickmarkPlacement) {
    $this->tickmarkPlacement = $tickmarkPlacement;
  }

  /**
   * Get Show Last Label.
   *
   * @return mixed
   *   Show Last Label.
   */
  public function getShowLastLabel() {
    return $this->showLastLabel;
  }

  /**
   * Get Show Last Label.
   *
   * @param mixed $showLastLabel
   *   Show Last Label.
   */
  public function setShowLastLabel($showLastLabel) {
    $this->showLastLabel = $showLastLabel;
  }

  /**
   * Get End On Tick.
   *
   * @return mixed
   *   End On Tick.
   */
  public function getEndOnTick() {
    return $this->endOnTick;
  }

  /**
   * Set End On Tick.
   *
   * @param mixed $endOnTick
   *   End On Tick.
   */
  public function setEndOnTick($endOnTick) {
    $this->endOnTick = $endOnTick;
  }

  /**
   * Get Line Width.
   *
   * @return int
   *   Line Width.
   */
  public function getLineWidth() {
    return $this->lineWidth;
  }

  /**
   * Set Line Width.
   *
   * @param int $lineWidth
   *   Line Width.
   */
  public function setLineWidth($lineWidth) {
    $this->lineWidth = $lineWidth;
  }

  /**
   * Get Grid Line Interpolation.
   *
   * @return mixed
   *   Grid Line Interpolation.
   */
  public function getGridLineInterpolation() {
    return $this->gridLineInterpolation;
  }

  /**
   * Set Grid Line Interpolation.
   *
   * @param mixed $gridLineInterpolation
   *   Grid Line Interpolation.
   */
  public function setGridLineInterpolation($gridLineInterpolation) {
    $this->gridLineInterpolation = $gridLineInterpolation;
  }

  /**
   * Json Serialize.
   *
   * @return array
   *   Json Serialize.
   */
  #[\ReturnTypeWillChange]
  public function jsonSerialize() {
    $vars = get_object_vars($this);

    return $vars;
  }

}
